==> kazehakase-0.0.9.1.tar.gz: kazehakase-0.0.9.1/src/kz-bookmark-menu.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2003 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-bookmark-menu.h,v 1.2 2003/10/23 19:22:24 makeinu Exp $
 */

#ifndef __KZ_BOOKMARK_MENU_H__
#define __KZ_BOOKMARK_MENU_H__

#include <gtk/gtk.h>

#include "kz-window.h"
#include "kz-remote-bookmark.h"

G_BEGIN_DECLS

#define KZ_TYPE_BOOKMARK_MENU		(kz_bookmark_menu_get_type ())
#define KZ_BOOKMARK_MENU(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_BOOKMARK_MENU, KzBookmarkMenu))
#define KZ_BOOKMARK_MENU_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass),  KZ_TYPE_Bookmark_MENU, KzBookmarkMenuClass))
#define KZ_IS_BOOKMARK_MENU(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_BOOKMARK_MENU))
#define KZ_IS_BOOKMARK_MENU_CLASS(klass)(G_TYPE_CHECK_CLASS_TYPE ((klass),  KZ_TYPE_BOOKMARK_MENU))
#define KZ_BOOKMARK_MENU_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj),  KZ_TYPE_Bookmark_MENU, KzBookmarkMenuClass))

typedef struct _KzBookmarkMenu           KzBookmarkMenu;
typedef struct _KzBookmarkMenuClass      KzBookmarkMenuClass;

struct _KzBookmarkMenu
{
	GtkHBox parent;

	/* Parent Kazehakase */
	KzWindow *kz;

	/* widget */
	GtkWidget *menu_item;
	GtkWidget *sub_menu;
	GtkWidget *update_button;
	GtkWidget *image;

	KzBookmark *bookmark;
};

struct _KzBookmarkMenuClass
{
	GtkHBoxClass parent_class;
};

GtkType    kz_bookmark_menu_get_type (void);
GtkWidget *kz_bookmark_menu_new      (KzWindow *kz, KzBookmark *bookmark);

G_END_DECLS

#endif /* __KZ_BOOKMARK_MENU_H__ */

==> kazehakase-0.1.0.tar.gz: kazehakase-0.1.0/src/kz-bookmark-menu.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2003 Hiroyuki Ikezoe
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-bookmark-menu.h,v 1.7 2003/11/16 14:44:25 makeinu Exp $
 */

#ifndef __KZ_BOOKMARK_MENU_H__
#define __KZ_BOOKMARK_MENU_H__

#include <gtk/gtk.h>

#include "kz-window.h"
#include "kz-bookmark.h"

G_BEGIN_DECLS

GtkWidget *kz_bookmark_menu_create_menuitem  (KzBookmark *bookmark,
					      KzWindow   *kz,
					      gboolean    is_folder_proxy);
GtkWidget *kz_bookmark_menu_create_submenu   (KzBookmark *folder,
					      KzWindow   *kz);

void       kz_boommark_menu_append_menuitems (GtkMenuShell *shell,
					      KzWindow     *kz,
					      KzBookmark   *folder);
void       kz_boommark_menu_remove_menuitems (GtkMenuShell *shell,
					      KzWindow     *kz);

G_END_DECLS

#endif /* __KZ_BOOKMARK_MENU_H__ */
